1.5.1
=====

Refresh packaging.

1.5
===

Added a ``Projection`` class providing a much simpler
interface than DictFilter.

1.4.1
=====

#3: Fixed less-than-equal and greater-than-equal comparisons
in ``Least`` and ``Greatest``.

1.4
===

Added ``Least`` and ``Greatest`` classes, instances of
which always compare lesser or greater than all other
objects.

1.3.2
=====

Fixed failure of KeyTransformingDict to transform keys
on calls to ``.get``.

1.3
===

Moved hosting to Github.

1.2.2
=====

Restore Python 2.7 compatibility.

1.2
===

Add InstrumentedDict.

1.1
===

Conditionally require setup requirements.

1.0
===

Initial functionality taken from jaraco.util 10.8.
